Struct debian_packaging::repository::s3::S3Writer[][src]

pub struct S3Writer { /* fields omitted */ }

Implementations

Create a new S3 writer bound to a named bucket with optional key prefix.

This will construct a default AWS Client.

Create a new S3 writer bound to a named bucket, optional key prefix, with an AWS Client.

This is like Self::new() except the caller can pass in the AWS Client to use.

Compute the S3 key name given a repository relative path.