Function debian_packaging::repository::reader_from_str [−][src]
pub fn reader_from_str(
s: impl ToString
) -> Result<Box<dyn RepositoryRootReader>>Expand description
Construct a RepositoryRootReader from a string/URL.
If the string contains :// it will be parsed as a URL. file://, http://,
and https:// are recognized.
Otherwise the string will be interpreted as a filesystem path. No test for whether the repository exists is performed.